# SpectroMiner
Spectrominer is a software that allows you to apply corrections to mass spectrometry data.
More precisely, it uses control measures in order to subtract the natural presence of isotopes.


## Installation
### Windows
see the [releases](https://github.com/ulaval-rs/spectrominer/releases)

To run spectrominer, run the .exe.

### Macos
see the [releases](https://github.com/ulaval-rs/spectrominer/releases)

### PyPi
To install:
```bash
$ pip install spectrominer
```
To run spectrominer:
```bash
$ spectrominer
```
or
```bash
$ /path/to/python/bin/spectrominer
```
